@@ -21,27 +21,11 @@ from transformers import PreTrainedTokenizer, BatchEncoding
 
 from collections.abc import Mapping
 from transformers.utils import (
-    EntryNotFoundError,
-    ExplicitEnum,
     PaddingStrategy,
-    PushToHubMixin,
-    RepositoryNotFoundError,
-    RevisionNotFoundError,
     TensorType,
-    add_end_docstrings,
-    cached_path,
-    copy_func,
-    get_file_from_repo,
-    hf_bucket_url,
-    is_flax_available,
-    is_offline_mode,
-    is_remote_url,
     is_tf_available,
-    is_tokenizers_available,
     is_torch_available,
-    logging,
-    to_py_obj,
-    torch_required,
+    to_py_obj
 )
 import sentencepiece as spm
 
